@@ -3,13 +3,16 @@
 #'
 #' @description Converts Surv object into a 3-column matrix
 #' 
-#' @details The third column of the returned matrix (type) has the following meanings:
+#' @details The third column of the returned matrix (type) has the following 
+#' meanings:
 #' 
 #'  1  -- no censoring
 #'  
-#'  2  -- left censored ("less than in a survival sense", e.g., [-Inf to 10], <10)
+#'  2  -- left censored ("less than in a survival sense"
+#'  , e.g., [-Inf to 10], <10)
 #'  
-#'  3  -- interval censored ("less than in a water quality sense", e.g., "0 - <3", "1 - 3")
+#'  3  -- interval censored ("less than in a water quality sense", 
+#'  e.g., "0 - <3", "1 - 3")
 #'  
 #'  NA -- missing value
 #'  
@@ -21,18 +24,21 @@
 #' @param col_hi Output column name for "hi" values.  Default = "hi"
 #' 
 #' @examples 
-#' df1 <- dataCensored[dataCensored$station=="CB3.3C","chla"][1:30]
+#' df1 <- dataCensored[dataCensored$station=="CB3.3C"
+#'           & dataCensored$date < as.POSIXct("1985-08-01") 
+#'           , c("station","date","chla")]
 #' colnames(df1)
 #' # Default values
-#' df2 <- unSurv(df1)
-#' colnames(df2)
+#' chla_1 <- unSurv(df1$chla)
+#' colnames(chla_1)
 #' # User values
-#' df3 <- unSurv(df1, "LOW", "HIGH")
-#' colnames(df3)
+#' chla_2 <- unSurv(df1$chla, "LOW", "HIGH")
+#' colnames(chla_2)
 #' 
 #' @return Returns a 3-column matrix: lo, hi, type
 #' 
-#' @seealso \code{\link{makeSurvDF}},  \code{\link{unSurvDF}},  \code{\link{impute}},  \code{\link{imputeDF}},  \code{\link{saveDF}},  
+#' @seealso \code{\link{makeSurvDF}},  \code{\link{unSurvDF}}
+#' ,  \code{\link{impute}},  \code{\link{imputeDF}},  \code{\link{saveDF}},  
 #' 
 #' @export
 # ####
@@ -40,15 +46,22 @@ unSurv <- function(x, col_lo = "lo", col_hi = "hi") {
   # extract lo and hi columns from Surv objects and place into a 3 column matrix
   type <- x[ , 3]
   
-  indx.0  <- !is.na(type) &  type == 0 # right censored ("greater thans in a survival sense" [10 to Inf], e.g., >1000)
-  indx.1  <- !is.na(type) &  type == 1 # no censoring
-  indx.2  <- !is.na(type) &  type == 2 # left censored ("less than in a survival sense" [-Inf to 10], i.e., <10)
-  indx.3  <- !is.na(type) &  type == 3 # interval censored ("less than in a water quality sense", i.e., "0 - <3", "1 - 3")
-  indx.NA <-  is.na(type)                # missing value
+  indx.0  <- !is.na(type) &  type == 0 
+# right censored ("greater thans in a survival sense" [10 to Inf], e.g., >1000)
+  indx.1  <- !is.na(type) &  type == 1 
+# no censoring
+  indx.2  <- !is.na(type) &  type == 2 
+# left censored ("less than in a survival sense" [-Inf to 10], i.e., <10)
+  indx.3  <- !is.na(type) &  type == 3 
+# interval censored ("less than in a water quality sense", i.e., "0 - <3"
+  #, "1 - 3")
+  indx.NA <-  is.na(type)               
+# missing value
   
   hi <- lo  <- x[, 1]         # default:    set hi and lo to 1st column of x
   hi[indx.3]  <- x[indx.3, 2] # int. cens:  replace hi with 2nd column of x 
-  lo[indx.2]  <- -Inf         # left cens:  replace lo with -Inf for 'survival-based' less thans
+  lo[indx.2]  <- -Inf         
+  # left cens:  replace lo with -Inf for 'survival-based' less thans
   hi[indx.0]  <- Inf          # right cens: replace hi with Inf 
   
   df_result <- cbind(lo,hi,type)
@@ -79,7 +92,8 @@ unSurv <- function(x, col_lo = "lo", col_hi = "hi") {
 #' 
 #' @return Returns dataframe with censored data converted to lo/hi format
 #' 
-#' @seealso \code{\link{makeSurvDF}},  \code{\link{unSurv}},  \code{\link{impute}},  \code{\link{imputeDF}},  \code{\link{saveDF}},  
+#' @seealso \code{\link{makeSurvDF}},  \code{\link{unSurv}}
+#' ,  \code{\link{impute}},  \code{\link{imputeDF}},  \code{\link{saveDF}},  
 #' 
 #' @export
 # ####
